microTC
==================================

.. image:: https://travis-ci.org/INGEOTEC/microtc.svg?branch=master
   :target: https://travis-ci.org/INGEOTEC/microtc

.. image:: https://ci.appveyor.com/api/projects/status/afcwh0d9sw6g937h/branch/master?svg=true
   :target: https://ci.appveyor.com/project/mgraffg/microtc/branch/master

.. image:: https://coveralls.io/repos/github/INGEOTEC/microtc/badge.svg?branch=master
   :target: https://coveralls.io/github/INGEOTEC/microtc?branch=master

.. image:: https://anaconda.org/ingeotec/microtc/badges/version.svg
   :target: https://anaconda.org/ingeotec/microtc

.. image:: https://badge.fury.io/py/microtc.svg
   :target: https://badge.fury.io/py/microtc

.. image:: https://anaconda.org/ingeotec/microtc/badges/downloads.svg   
   :target: https://anaconda.org/ingeotec/microtc

.. image:: https://readthedocs.org/projects/microtc/badge/?version=latest 	    
   :target: https://microtc.readthedocs.io/en/latest/?badge=latest

microTC is a minimalist text classifier, that is, it is designed to tackle text-classification problems in an agnostic way,
being both domain and language independent. 

microTC is intentionally simple, so only a small number of features
were implemented. However, it uses a some complex tools from numpy
and scikit-lean. The number of dependencies is limited and fulfilled
by almost any Scientific Python distributions, e.g., `Anaconda <https://www.continuum.io/downloads>`_.

The documentation is on `readthedocs <https://microtc.readthedocs.io>`_.
